@@ -1906,7 +1906,7 @@ static int pyg_thread_state_tls_key = -1;
 /* Enable threading; note that the GIL must be held by the current
    thread when this function is called */
 static int
-pyg_enable_threads ()
+pyg_enable_threads (void)
 {
     if (getenv ("PYGTK_USE_GIL_STATE_API"))
 	use_gil_state_api = TRUE;
@@ -2717,6 +2717,7 @@ initgobject(void)
     gerror_exc = PyErr_NewException("gobject.GError", PyExc_RuntimeError,NULL);
     PyDict_SetItemString(d, "GError", gerror_exc);
 
+    PyGObject_MetaType.tp_base = &PyType_Type;
     PyGObject_MetaType.tp_traverse = PyType_Type.tp_traverse;
     PyGObject_MetaType.tp_clear = PyType_Type.tp_clear;
     PyGObject_MetaType.tp_is_gc = PyType_Type.tp_is_gc;
